==> huhk-1.9.1.tar.gz: huhk-1.9.1/service/app_a/asserts/content/asserts_content_campmanager.py <==
import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_campmanager import SqlsContentCampmanager


class AssertsContentCampmanager(SqlsContentCampmanager):
    @allure.step(title="接口返回结果校验")
    def assert_content_campmanager_page(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_campmanager_page(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["id", "sortord", "sortBody", "createBy", "name", "status"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_campmanager_soldout(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_campmanager_soldout(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["id", "campId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_campmanager_insertcampid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_campmanager_insertcampid(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_campmanager_insert(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_campmanager_insert(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["id", "city", "campDetail", "campTradeTime", "url", "content", "county", "ownerDiscount", "address", "discountExpEndTime", "province", "name", "discountExpBeginTime"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_campmanager_detail_(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_campmanager_detail_(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["id"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_campmanager_update(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_campmanager_update(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["phone", "ownerDiscount", "discountExpEndTime", "areaCode", "discountExpBeginTime"])
        assert True, "数据比较不一致"

==> huhk-1.9.6.tar.gz: huhk-1.9.6/service/app_a/asserts/content/asserts_content_campmanager.py <==
import allure

from service.app_a import unit_request
from service.app_a.sqls.content.sqls_content_campmanager import SqlsContentCampmanager


class AssertsContentCampmanager(SqlsContentCampmanager):
    @allure.step(title="接口返回结果校验")
    def assert_content_campmanager_page(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_campmanager_page(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["createBy", "name", "sortBody", "status", "sortord", "id"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_campmanager_soldout(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_campmanager_soldout(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["id", "campId"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_campmanager_insertcampid(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_campmanager_insertcampid(**kwargs)
        # flag = self.compare_json_list(self.res, out, [])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_campmanager_insert(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_campmanager_insert(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["campDetail", "county", "ownerDiscount", "name", "discountExpBeginTime", "address", "url", "city", "province", "campTradeTime", "content", "id", "discountExpEndTime"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_campmanager_detail_(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_campmanager_detail_(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["id"])
        assert True, "数据比较不一致"

    @allure.step(title="接口返回结果校验")
    def assert_content_campmanager_update(self, _assert=True, **kwargs):
        assert unit_request.is_assert_true(self.res, _assert), "校验接口返回，缺少成功标识"
        # out = self.sql_content_campmanager_update(**kwargs)
        # flag = self.compare_json_list(self.res, out, ["ownerDiscount", "discountExpBeginTime", "phone", "areaCode", "discountExpEndTime"])
        assert True, "数据比较不一致"
